//
//  ESCore.m
//  DiceView
//
//  Created by kunii on 10/03/29.
//  Copyright 2010 Apple Inc. All rights reserved.
//

#import "ESCore.h"
#import "Light.h"
#import "DiceGL.h"

@implementation ESCore
@synthesize cube;

-(id)init {
	if (self = [super init]) {
		light = [[Light alloc] init];
		cube = [[DiceGL alloc] init];
	}
	return self;
}

-(void)deleteGLBuffer {
    if(depthRenderbuffer) {
		glDeleteRenderbuffersOES(1, &depthRenderbuffer);
		depthRenderbuffer = 0;
	}
}

-(void)dealloc {
	[light release];
	[cube release];
	[super dealloc];
}

-(void)draw {
    GLint backingWidth;
    GLint backingHeight;
    glGetRenderbufferParameterivOES(GL_RENDERBUFFER_OES, GL_RENDERBUFFER_WIDTH_OES, &backingWidth);
    glGetRenderbufferParameterivOES(GL_RENDERBUFFER_OES, GL_RENDERBUFFER_HEIGHT_OES, &backingHeight);

	double aspect = (double)backingHeight / (double)backingWidth;

    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();
	glFrustumf(-1, 1, -aspect, aspect, 3, 1000.0f);
	glTranslatef(0, 0, -7);
	[light on];	
	[cube draw];
}

-(void)resetViewWidth:(GLint)backingWidth height:(GLint)backingHeight {
	//	Zバッファ確保
    if(depthRenderbuffer) {
        glDeleteRenderbuffersOES(1, &depthRenderbuffer);
        depthRenderbuffer = 0;
    }
	glGenRenderbuffersOES(1, &depthRenderbuffer);	//	depthRenderbufferにOpenGL ESシステム側からレンダリング用の固有値（名称）を設定してもらう
	glBindRenderbufferOES(GL_RENDERBUFFER_OES, depthRenderbuffer);	//	OpenGL ESシステム側にレンダリング用として認識させる
	glRenderbufferStorageOES(GL_RENDERBUFFER_OES, GL_DEPTH_COMPONENT16_OES, backingWidth, backingHeight);	//	Zバッファとして
	glFramebufferRenderbufferOES(GL_FRAMEBUFFER_OES, GL_DEPTH_ATTACHMENT_OES, GL_RENDERBUFFER_OES, depthRenderbuffer);	//	フレームにZバッファを登録
}

@end
